@@ -1,9 +1,9 @@
 __author__ = 'Lene Preuss <lene.preuss@gmail.com>'
 
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Tuple
+from typing import Any, Callable, List, Tuple
+from PIL import Image
 
-AlgorithmOptions = Dict[str, float]
-ComparisonFunction = Callable[[Path, Path, AlgorithmOptions], bool]
+HashFunction = Callable[[Image.Image], int]
 ActionFunction = Callable[[Tuple[Path, Path]], Any]
 Results = List[Tuple[Path, Path]]
