@@ -1,16 +1,15 @@
 __author__ = 'Lene Preuss <lene.preuss@gmail.com>'
 
 import logging
-from functools import lru_cache, partial
+from functools import lru_cache
 from hashlib import sha256
 from pathlib import Path
 from subprocess import call  # noqa: S404
 from typing import Dict, Tuple, List
 
-from duplicate_images.function_types import ActionFunction, AlgorithmOptions, ComparisonFunction
-from duplicate_images.histogram import compare_image_histograms
-from duplicate_images.image_wrapper import ImageWrapper
-from duplicate_images.image_hash import is_similar, IMAGE_HASH_ALGORITHM
+import imagehash
+
+from duplicate_images.function_types import ActionFunction
 
 
 @lru_cache(maxsize=None)
@@ -23,38 +22,11 @@ def get_hash(file: Path) -> str:
     return sha256(file.open('rb').read()).hexdigest()
 
 
-def compare_exactly(
-        file: Path, other_file: Path, options: AlgorithmOptions  # pylint: disable=unused-argument
-) -> bool:
+def compare_exactly(file: Path, other_file: Path) -> bool:
     """Returns True if file and other_file are exactly exactly_equal"""
     return get_size(other_file) == get_size(file) and get_hash(file) == get_hash(other_file)
 
 
-def compare_histograms(
-        file: Path, other_file: Path, options: AlgorithmOptions
-) -> bool:
-    """Returns True if the histograms of file and other_file differ by
-       less than rms_error"""
-    aspect_fuzziness = options['aspect_fuzziness']
-    rms_error = options['rms_error']
-    try:
-        return compare_image_histograms(
-            ImageWrapper.create(file), ImageWrapper.create(other_file), aspect_fuzziness, rms_error
-        )
-    except (IOError, TypeError):
-        return False
-
-
-def compare_image_hash(
-        algo: str, file: Path, other_file: Path,
-        options: AlgorithmOptions  # pylint: disable=unused-argument
-) -> bool:
-    return is_similar(
-        ImageWrapper.create(file), ImageWrapper.create(other_file),
-        IMAGE_HASH_ALGORITHM[algo]
-    )
-
-
 def ascending_by_size(pair: Tuple[Path, Path]) -> List[Path]:
     return sorted(pair, key=lambda path: path.stat().st_size)
 
@@ -76,12 +48,13 @@ def quote_print(pair: Tuple[Path, Path]) -> None:
     print(f"{quotes[0]}{pair[0]}{quotes[0]} {quotes[1]}{pair[1]}{quotes[1]}")
 
 
-COMPARISON_METHODS: Dict[str, ComparisonFunction] = {
-    'exact': compare_exactly,
-    'histogram': compare_histograms,
+IMAGE_HASH_ALGORITHM = {
+    'ahash': imagehash.average_hash,
+    'colorhash': imagehash.colorhash,
+    'dhash': imagehash.dhash,
+    'phash': imagehash.phash,
+    'whash': imagehash.whash
 }
-for key in IMAGE_HASH_ALGORITHM:
-    COMPARISON_METHODS[key] = partial(compare_image_hash, key)
 
 ACTIONS_ON_EQUALITY: Dict[str, ActionFunction] = {
     'delete-first': lambda pair: delete_with_log_message(pair[0]),
